@@ -2,13 +2,16 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
-use scroll::{IOread, Pread, SizeWith};
+use {
+    scroll::{IOread, IOwrite, Pread, SizeWith},
+    std::fmt::{Display, Formatter},
+};
 
 /// A XAR archive header.
 ///
 /// The header effectively defines a table of contents, which
 /// holds information about the content of the archive.
-#[derive(Clone, Copy, Debug, IOread, Pread, SizeWith)]
+#[derive(Clone, Copy, Debug, IOread, IOwrite, Pread, SizeWith)]
 pub struct XarHeader {
     /// File magic. `xar!`.
     pub magic: u32,
@@ -51,3 +54,29 @@ impl From<u32> for XarChecksum {
         }
     }
 }
+
+impl Into<u32> for XarChecksum {
+    fn into(self) -> u32 {
+        match self {
+            Self::None => 0,
+            Self::Sha1 => 1,
+            Self::Md5 => 2,
+            Self::Sha256 => 3,
+            Self::Sha512 => 4,
+            Self::Other(v) => v,
+        }
+    }
+}
+
+impl Display for XarChecksum {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            XarChecksum::None => f.write_str("none"),
+            XarChecksum::Sha1 => f.write_str("SHA-1"),
+            XarChecksum::Md5 => f.write_str("MD5"),
+            XarChecksum::Sha256 => f.write_str("SHA-256"),
+            XarChecksum::Sha512 => f.write_str("SHA-512"),
+            XarChecksum::Other(v) => f.write_fmt(format_args!("unknown ({})", v)),
+        }
+    }
+}
